{% load i18n horizon humanize %}

{% block help_message %}
<h4>{% blocktrans %}Session{% endblocktrans %}</h4>

<p>{% blocktrans %}A group of jobs which share the same scheduling time.{% endblocktrans %}</p>

<link rel="stylesheet" href="{{ STATIC_URL }}freezer/css/bootstrap-datetimepicker.min.css">
<script type='text/javascript' src='{{ STATIC_URL }}freezer/js/vendor/moment.js'></script>
<script type='text/javascript' src='{{ STATIC_URL }}freezer/js/vendor/bootstrap-datetimepicker.js'></script>
<script type='text/javascript' src='{{ STATIC_URL }}freezer/js/freezer.datetimepicker.js'></script>

{% endblock %}